==> openshift-model-monitoring-6.7.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/OpsGenieConfigResponderBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpsGenieConfigResponderBuilder extends OpsGenieConfigResponderFluentImpl<OpsGenieConfigResponderBuilder> implements VisitableBuilder<OpsGenieConfigResponder,OpsGenieConfigResponderBuilder>{
  public OpsGenieConfigResponderBuilder() {
    this(false);
  }
  public OpsGenieConfigResponderBuilder(Boolean validationEnabled) {
    this(new OpsGenieConfigResponder(), validationEnabled);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent) {
    this(fluent, false);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpsGenieConfigResponder(), validationEnabled);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent,OpsGenieConfigResponder instance) {
    this(fluent, instance, false);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent,OpsGenieConfigResponder instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withId(instance.getId());
      fluent.withName(instance.getName());
      fluent.withType(instance.getType());
      fluent.withUsername(instance.getUsername());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponder instance) {
    this(instance,false);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponder instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withId(instance.getId());
      this.withName(instance.getName());
      this.withType(instance.getType());
      this.withUsername(instance.getUsername());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OpsGenieConfigResponderFluent<?> fluent;
  Boolean validationEnabled;
  public OpsGenieConfigResponder build() {
    OpsGenieConfigResponder buildable = new OpsGenieConfigResponder(fluent.getId(),fluent.getName(),fluent.getType(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/OpsGenieConfigResponderBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpsGenieConfigResponderBuilder extends OpsGenieConfigResponderFluent<OpsGenieConfigResponderBuilder> implements VisitableBuilder<OpsGenieConfigResponder,OpsGenieConfigResponderBuilder>{
  public OpsGenieConfigResponderBuilder() {
    this(false);
  }
  public OpsGenieConfigResponderBuilder(Boolean validationEnabled) {
    this(new OpsGenieConfigResponder(), validationEnabled);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent) {
    this(fluent, false);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpsGenieConfigResponder(), validationEnabled);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent,OpsGenieConfigResponder instance) {
    this(fluent, instance, false);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponderFluent<?> fluent,OpsGenieConfigResponder instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new OpsGenieConfigResponder());

    if (instance != null) {
      fluent.withId(instance.getId());
      fluent.withName(instance.getName());
      fluent.withType(instance.getType());
      fluent.withUsername(instance.getUsername());
      fluent.withId(instance.getId());
      fluent.withName(instance.getName());
      fluent.withType(instance.getType());
      fluent.withUsername(instance.getUsername());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponder instance) {
    this(instance,false);
  }
  public OpsGenieConfigResponderBuilder(OpsGenieConfigResponder instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new OpsGenieConfigResponder());

    if (instance != null) {
      this.withId(instance.getId());
      this.withName(instance.getName());
      this.withType(instance.getType());
      this.withUsername(instance.getUsername());
      this.withId(instance.getId());
      this.withName(instance.getName());
      this.withType(instance.getType());
      this.withUsername(instance.getUsername());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OpsGenieConfigResponderFluent<?> fluent;
  Boolean validationEnabled;
  public OpsGenieConfigResponder build() {
    OpsGenieConfigResponder buildable = new OpsGenieConfigResponder(fluent.getId(),fluent.getName(),fluent.getType(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
